#!/bin/bash
#
MAJOR_VERSION="2"

set -e -u

cd ..

script="version.sh"
runscript="original-version.sh"

if [ -d .git ]
then

	[ -f $runscript ] || {
		echo "renaming original script: $script -> $runscript"
		mv $script $runscript
	}

	# the original script detects changes in the source tree, and
	# mark the version with character 'M' if found any
	#
	# since we modify the script itself, this is alwasy true, so we
	# remove the M marker (we don't really change anything in the
	# source tree)
	#
	out=$(./$runscript | sed -e 's/M//')

	echo "#!/bin/sh
	echo '$out'
	exit 0
	" >$script
	chmod +x $script
	echo -e "script '$script' created\n"
	echo -e "it's safe to remove .git directory, now, to clean source package\n"
else
	echo -e "\nWARNING: .git directory not found, using actual '$script'\n"
fi

out=$(./$script)
echo "$out"

# update 'install' file
#
version=$(echo "$out" | grep X264_POINTVER | sed -e 's/.*VER "//' -e 's/ .*//')
pkgversion="$MAJOR_VERSION:$version"
subversion=$(echo "$version" | sed -e 's/^[0-9]\.//' -e 's/\..*//')

echo -e "\nupdating ku/install using version: '$pkgversion'\n"
sed -e "s/^:VERSION.*/:VERSION	$pkgversion/" ku/install >ku/install.new || exit $?
mv ku/install.new ku/install

echo -e "\nupdating debian.in/control using subversion: '$subversion'\n"
sed -e "s/@SUBVERSION@/$subversion/g" ku/control >debian.in/control

exit 0
